@@ -7,10 +7,10 @@
     :license: MIT, see LICENSE for more details.
 """
 
-__version__ = '0.2.1'
+__version__ = '0.2.2'
 
 from .dicts import recursive_dict, scrub_dict, to_dict, recursive_dict_to_dict
 from .charsets import int_to_charset, charset_to_int, change_charset
-from .base16 import is_hex, is_int, hex_to_int, int_to_hex, charset_to_hex, \
-    hexpad
+from .base16 import hex_to_int, int_to_hex, hex_to_charset, charset_to_hex, \
+    hexpad, is_hex, is_int, is_valid_int
 from .entropy import dev_urandom_entropy, dev_random_entropy
