@@ -11,12 +11,7 @@ import string
 from .charsets import change_charset
 
 B16_CHARS = string.hexdigits[0:16]
-
-def hexpad(x):
-    return ('0' * (len(x) % 2)) + x
-
-def charset_to_hex(s, original_charset):
-    return hexpad(change_charset(s, original_charset, B16_CHARS))
+B16_REGEX = '^[0-9a-f]*$'
 
 def hex_to_int(s):
     try:
@@ -31,6 +26,9 @@ def int_to_hex(i):
         raise ValueError("Value must be in int format")
 
 def is_hex(s):
+    # make sure that s is a string
+    if not isinstance(s, str):
+        return False
     # if there's a leading hex string indicator, strip it
     if s[0:2] == '0x':
         s = s[2:]
@@ -43,7 +41,10 @@ def is_hex(s):
         return True
 
 def is_int(i):
-    if isinstance(i, (int,long)):
+    return isinstance(i, (int,long))
+
+def is_valid_int(i):
+    if is_int(i):
         return True
     elif isinstance(i, str):
         try:
@@ -52,5 +53,16 @@ def is_int(i):
             return False
         else:
             return True
-    else:
-        return False
+    return False
+
+def hexpad(x):
+    return ('0' * (len(x) % 2)) + x
+
+def charset_to_hex(s, original_charset):
+    return hexpad(change_charset(s, original_charset, B16_CHARS))
+
+def hex_to_charset(s, destination_charset):
+    if not is_hex(s):
+        raise ValueError("Value must be in hex format")
+    s = s.lower()
+    return change_charset(s, B16_CHARS, destination_charset)
